@@ -1,6 +1,5 @@
-from copy import deepcopy
-import pandas as pd
 import numpy as np
+import pandas as pd
 
 
 def get_group(pid, groups):
@@ -9,19 +8,19 @@ def get_group(pid, groups):
 
     Parameters
     ----------
-    pid: 
-        type: str 
+    pid:
+        type: str
         page_id to conpute the group for.
-    groups: 
-        type: dict 
+    groups:
+        type: dict
         Maps the group to the page ids.
-        
+
     Returns
     -------
-    str 
+    str
     """
 
-    group_out = 'no_group'
+    group_out = "no_group"
     try:
         for group in groups:
             if pid in groups[group]:
@@ -33,25 +32,30 @@ def get_group(pid, groups):
 
 def discretize(df, from_column, to_column=None, n_groups=10):
     """
-    This functions discretizes de column 'from_column' into the column 'to_column' in the 
+    This functions discretizes de column 'from_column' into the column 'to_column' in the
     dataframe df.
 
     Parameters
     ----------
-    n_groups: 
-        type: str 
+    n_groups:
+        type: str
         Number of groups to split the column 'from_column'.
         default=10
-        
+
     Returns
     -------
-    None 
+    None
     """
     if from_column in df.keys():
         if to_column:
-            df[to_column] = pd.cut(df[from_column], n_groups, labels=range(1, n_groups + 1))
+            df[to_column] = pd.cut(
+                df[from_column], n_groups, labels=range(1, n_groups + 1)
+            )
         else:
-            df[f'disc_{from_column}'] = pd.cut(
-                df[from_column], n_groups, labels=range(1, n_groups + 1))
+            df[f"disc_{from_column}"] = pd.cut(
+                df[from_column], n_groups, labels=range(1, n_groups + 1)
+            )
     else:
-        raise RuntimeError(f'{from_column} is not a column available of input DataFrame.')
+        raise RuntimeError(
+            f"{from_column} is not a column available of input DataFrame."
+        )
